@@ -25,7 +25,7 @@ import pandas as pd
 
 """ Simple way to plot raster file """
 
-def show_fig(image, title=None, color='Spectral', ctitle='colorbar title', bounds=None, res=None, vmin=None, vmax=None, savefig=False):
+def show_fig(image, title=None, color='Spectral', ctitle='', bounds=None, res=None, vmin=None, vcenter=None, vmax=None, savefig=False):
     """
 	Plotting a raster file
 		image: input array (array-like) (e.g. rasterio.open('raster.tif').read(1))
@@ -35,17 +35,22 @@ def show_fig(image, title=None, color='Spectral', ctitle='colorbar title', bound
 		bounds: raster plot bounds, input: (left, right, bottom, top) (floats) 
 		res: raster pixel resolution (int or float)
 		vmin, vmax: plot minimum and maximum (int or float)
+		vcenter: center of colormap
 		savefig: If true, figure is saved as a .jpg in the current directory with the filename being the title input (boolean)
     """
     fig, ax = plt.subplots(figsize=(12,6))
-    c = ax.imshow(image, cmap=color, extent=bounds, vmin=vmin, vmax=vmax)
+    if vcenter != None:
+    	divnorm = TwoSlopeNorm(vmin=vmin, vcenter=vcenter, vmax=vmax)
+    	c = ax.imshow(image, cmap=color, extent=bounds, norm=divnorm)
+    else:
+    	c = ax.imshow(image, cmap=color, extent=bounds, vmin=vmin, vmax=vmax)
     if res != None:
         ax.add_artist(ScaleBar(dx=res, units='m')) # add scalebar
     fig.colorbar(c, label=ctitle)
     fig.suptitle(title)
     plt.show()
     if savefig == True:
-        fig.savefig(title + '.jpg', dpi=1000) # to save the plot as a jpg image
+    	fig.savefig(title + '.jpg', dpi=500) # to save the plot as a jpg image
 
 
 """ Geoprocessing tools:
